Module event

Module event 

Runtime transaction event types. Runtime event classifications shared by runtime and plugin surfaces.

Structs

TxObservedEvent
Event emitted by runtime when a transaction is observed.

Enums

ForkSlotStatus
Runtime slot status classification for local fork/canonical tracking.
TxCommitmentStatus
Runtime commitment state for an observed transaction slot.
TxKind
Transaction classification used by runtime and plugins.