Function run_with_hosts
pub fn run_with_hosts(
plugin_host: PluginHost,
extension_host: RuntimeExtensionHost,
) -> Result<(), RuntimeError>Expand description
Runs the packaged observer runtime with explicit plugin and runtime extension hosts.
Errors
Returns any runtime initialization or shutdown error from the underlying observer runtime.