Struct PacketSubscription
pub struct PacketSubscription {
pub source_kind: Option<RuntimePacketSourceKind>,
pub transport: Option<RuntimePacketTransport>,
pub event_class: Option<RuntimePacketEventClass>,
pub local_addr: Option<SocketAddr>,
pub local_port: Option<u16>,
pub remote_addr: Option<SocketAddr>,
pub remote_port: Option<u16>,
pub owner_extension: Option<String>,
pub resource_id: Option<String>,
pub shared_tag: Option<String>,
pub websocket_frame_type: Option<RuntimeWebSocketFrameType>,
}Expand description
Immutable packet subscription filter declared in extension startup manifest.
Fields
source_kind: Option<RuntimePacketSourceKind>Match on source kind.
transport: Option<RuntimePacketTransport>Match on transport category.
event_class: Option<RuntimePacketEventClass>Match on event class.
local_addr: Option<SocketAddr>Match on local endpoint exactly.
local_port: Option<u16>Match on local port.
remote_addr: Option<SocketAddr>Match on remote endpoint exactly.
remote_port: Option<u16>Match on remote port.
owner_extension: Option<String>Match on owning extension name.
resource_id: Option<String>Match on extension resource id.
Match on shared stream tag.
websocket_frame_type: Option<RuntimeWebSocketFrameType>Match on WebSocket frame type.
Implementations
impl PacketSubscription
impl PacketSubscription
pub fn matches(&self, event: &RuntimePacketEvent) -> bool
pub fn matches(&self, event: &RuntimePacketEvent) -> bool
Returns true when this subscription matches the provided runtime packet event.