Module runtime
Packaged runtime entrypoints for embedding SOF.
Structs
- Runtime
Setup - Programmatic runtime setup that mirrors selected SOF environment variables.
Enums
- Runtime
Error - Public runtime error surface for packaged SOF entrypoints.
Functions
- run
- Runs the packaged observer runtime on a Tokio multi-thread runtime.
- run_
async - Async variant of
run, for callers that already own a Tokio runtime. - run_
async_ with_ derived_ state_ host - Async variant of
run_with_derived_state_host. - run_
async_ with_ derived_ state_ host_ and_ setup - Async variant of
run_with_derived_state_host_and_setup. - run_
async_ with_ extension_ host - Async variant of
run_with_extension_host. - run_
async_ with_ extension_ host_ and_ setup - Async variant of
run_with_extension_host_and_setup. - run_
async_ with_ hosts - Async variant of
run_with_hosts. - run_
async_ with_ hosts_ and_ derived_ state_ host - Async variant of
run_with_hosts_and_derived_state_host. - run_
async_ with_ hosts_ and_ derived_ state_ host_ and_ setup - Async variant of
run_with_hosts_and_derived_state_host_and_setup. - run_
async_ with_ hosts_ and_ setup - Async variant of
run_with_hosts_and_setup. - run_
async_ with_ plugin_ host - Async variant of
run_with_plugin_host. - run_
async_ with_ plugin_ host_ and_ setup - Async variant of
run_with_plugin_host_and_setup. - run_
async_ with_ setup - Async variant of
run_with_setup, for callers that already own a Tokio runtime. - run_
with_ derived_ state_ host - Runs the packaged observer runtime with an explicit derived-state host.
- run_
with_ derived_ state_ host_ and_ setup - Runs the packaged observer runtime with a derived-state host and explicit setup overrides.
- run_
with_ extension_ host - Runs the packaged observer runtime with a custom runtime extension host.
- run_
with_ extension_ host_ and_ setup - Runs the packaged observer runtime with a custom runtime extension host and setup overrides.
- run_
with_ hosts - Runs the packaged observer runtime with explicit plugin and runtime extension hosts.
- run_
with_ hosts_ and_ derived_ state_ host - Runs the packaged observer runtime with explicit hosts, including derived-state consumers.
- run_
with_ hosts_ and_ derived_ state_ host_ and_ setup - Runs the packaged observer runtime with explicit hosts, a derived-state host, and setup overrides.
- run_
with_ hosts_ and_ setup - Runs the packaged observer runtime with explicit hosts and setup overrides.
- run_
with_ plugin_ host - Runs the packaged observer runtime with a custom plugin host.
- run_
with_ plugin_ host_ and_ setup - Runs the packaged observer runtime with a custom plugin host and explicit setup overrides.
- run_
with_ setup - Runs the packaged observer runtime with explicit code-driven setup overrides.