Function run_with_derived_state_host
pub fn run_with_derived_state_host(
derived_state_host: DerivedStateHost,
) -> Result<(), RuntimeError>Expand description
Runs the packaged observer runtime with an explicit derived-state host.
Errors
Returns any runtime initialization or shutdown error from the underlying observer runtime.